CapecDisplayType

Enum CapecDisplayType 

pub enum CapecDisplayType {
Show 18 variants All, Alternates, Attacks, Consequences, Description, Flow, Indicators, Instances, Likelihood, Name, Mitigations, Prerequisites, Resources, Severity, Skills, Taxonomy, TaxonomyMitreAttackIds, Weaknesses,
}
Enum representing different types of CAPEC information to display

Variants



All

Display all information



Alternates

Display alternates



Attacks

Display attacks



Consequences

Display Consequences



Description

Display description



Flow

Display flow



Indicators

Display indicators



Instances

Display instances



Likelihood

Display likelihood



Name

Display name



Mitigations

Display mitigations



Prerequisites

Display prerequisites



Resources

Display resources



Severity

Display severity



Skills

Display skills



Taxonomy

Display taxonomy



TaxonomyMitreAttackIds

Show only MITRE ATTACK ids



Weaknesses

Display weaknesses

Implementations

Source

impl CapecDisplayType

pub fn show(&self, capec_record: &CapecRecord)

Shows capec records elements according to the enum type that’s specifying what should be displayed.

Arguments
  • capec_record - The cwe records for displaying